
# Type: has numeric value


connects a quantity value to a number

URI: [biolink:has_numeric_value](https://w3id.org/biolink/vocab/has_numeric_value)


## Domain and Range

[QuantityValue](QuantityValue.md) ->  <sub>OPT</sub> [Double](types/Double.md)

## Parents


## Children


## Used by

 * [QuantityValue](QuantityValue.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | qud:quantityValue |
| **In Subsets:** | | samples |

